@@ -6,89 +6,11 @@ import time
 from . import config
 from .cachehandler import CacheHandler
 
-from .models.orders import OrderList, Order
-from .models.processes import ProcessStatus, ProcessLink
-from .models.errors import Error, Violation
-
 from .constants.reasons import *
 from .constants.transporters import *
 
-class APIEndpoint:
+from .endpoints.orders import OrderMethods
 
-    def __init__(self, api, endpoint):
-
-        self.api = api
-        self.endpoint = endpoint
-    
-
-class OrderMethods(APIEndpoint):
-
-    def __init__(self, api):
-        super(OrderMethods, self).__init__(api, "orders")
-
-    def list(self, page=1, method='FBR', status='ALL'):
-
-        data = { 'page' : page, 'method' : method, 'status' : status }
-        url = self.endpoint
-
-        status, respJson = self.api.get(url, data)
-        return OrderList().parse(respJson)
-
-    def get(self, id):
-
-        url = '{endpoint}/{id}'.format(endpoint=self.endpoint, id=id)
-        data = None
-
-        status, respJson = self.api.get(url, data)
-        if status == 404: return Error().parse(respJson)
-
-        return Order().parse(respJson)
-    
-    def cancelItem(self, id, reason):
-        data = { 'orderItems' : [{ 'orderItemId' : id, 'reasonCode' : reason }]}
-
-        url = '{endpoint}/cancellation'.format(endpoint=self.endpoint)
-
-        status, respJson = self.api.put(url, data)
-        if status == 400: return Error().parse(respJson)
-        
-        return ProcessStatus().parse(respJson)
-    
-    def cancel(self, order, reason):
-
-        orderItems = []
-        for item in order.orderItems:
-            orderItems.append({ 'orderItemId' : item.orderItemId, 'reasonCode' : reason })
-
-        data = { 'orderItems' : orderItems }
-
-        url = '{endpoint}/cancellation'.format(endpoint=self.endpoint)
-
-        status, respJson = self.api.put(url, data)
-        if status == 400: return Error().parse(respJson)
-
-        return ProcessStatus().parse(respJson)
-    
-    def ship(self, order, shipmentReference=None, shippingLabelId=None, transporterCode=None, trackAndTrace=None):
-
-        orderItems = []
-        for item in order.orderItems:
-            orderItems.append({ 'orderItemId' : item.orderItemId })
-        
-        data = { 'orderItems' : orderItems }
-
-        if shipmentReference: data['shipmentReference'] = shipmentReference
-        if shippingLabelId: data['shippingLabelId'] = shippingLabelId
-        if transporterCode:
-            data['transport'] = { 'transporterCode' : transporterCode }
-            if trackAndTrace: data['transport']['trackAndTrace'] = trackAndTrace
-        
-        url = '{endpoint}/shipment'.format(endpoint=self.endpoint)
-        
-        status, respJson = self.api.put(url, data)
-        if status == 400: return Error().parse(respJson)
-
-        return ProcessStatus().parse(respJson)
 
 class BolAPI:
 
