@@ -7,7 +7,8 @@ class OrderList(ObjectListModel):
     def __init__(self):
         super(OrderList, self).__init__(list=[])
 
-        self.errors = False
+        self.hasError = False
+        self.error = None
 
     @property
     def orders(self):
@@ -33,7 +34,9 @@ class Order(ObjectListModel):
         self.orderId = orderId
         self.billingDetails = billingDetails if billingDetails else CustomerDetails()
         self.shipmentDetails = shipmentDetails if shipmentDetails else CustomerDetails()
-        self.errors = False
+        
+        self.hasError = False
+        self.error = None
 
     @property
     def orderItems(self):
@@ -77,7 +80,9 @@ class OrderShipment(ObjectListModel):
         self.shipmentReference = shipmentReference
         self.shippingLabelId= shippingLabelId
         self.transport = transport if transport else Transport()
-        self.errors = False
+        
+        self.hasError = False
+        self.error = None
     
     @property
     def orderItems(self):
@@ -106,7 +111,9 @@ class OrderItem(BaseModel):
         self.quantityCancelled = quantityCancelled
         self.unitPrice = unitPrice
         self.comission = comission
-        self.errors = False
+
+        self.hasError = False
+        self.error = None
 
     def parse(self, json):
         super(OrderItem, self).parse(json)
@@ -150,4 +157,6 @@ class CustomerDetails(BaseModel):
         self.vatNumber = vatNumber
         self.kvkNumber = kvkNumber
         self.orderReference = orderReference
-        self.errors = False
\ No newline at end of file
+
+        self.hasError = False
+        self.error = None
\ No newline at end of file
